About Betty - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# About Betty

## Philosophy

Betty builds sites that tell a story. Raw family data is visualized in different, sometimes interactive ways. Additional information is added automatically from a variety of third-party sources, augmenting your family trees with further encyclopedic information, imagery, and maps.

## Name

Betty was named after Liberta “Betty” Lankester, grandmother to the original project author.

## What is Betty not?

Betty does not help you gather or manage the data for your family history. For that purpose, use a product such as Gramps, or a service like Ancestry.com.

## Find Betty on

- Twitter

- GitHub

- PyPI

## In this section

- Contributing to Betty

- Copyright & license

- Versions

- Sponsors